# Basic Tools    
A Module to do some problems like email validations , displaying pyramids probelms ...

## Installation
```pip install basicTools```

## How to use it
Install the module ,import it and use it (eg. basicTools.is_validEmail(email)).
checkout the gitHub page for more information of methods in this module.


## License
Copyright 2021 Jenifar
This repository is licensed under the MIT license.
See LICENSE for details